#!/usr/bin/env python
#
#   find-blob-list.py
#   zfilenet
#
#   Copyright (C) 2008 Ross Light
#
#   This file is part of zfilenet.
#
#   zfilenet is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   zfilenet is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with zfilenet.  If not, see <http://www.gnu.org/licenses/>.
#

"""
Server maintenence script

This writes to stdout a list of all blobs currently being used by the index
server.

usage: find-blob-list.py database
"""

import sqlite3
import sys

import progtools

__author__ = 'Ross Light'
__date__ = 'June 15, 2008'
__all__ = ['main']

@progtools.reportexits
def main(args=None):
    if args is None:
        args = sys.argv[1:]
    if len(args) != 1:
        raise progtools.UsageError()
    server_db = sqlite3.connect(args[0])
    cursor = server_db.cursor()
    cursor.execute("SELECT file_blob_list FROM files;")
    for (file_blob_data,) in cursor:
        for blob_id_hex in file_blob_data.split():
            sys.stdout.write(blob_id_hex + '\n')
    return 0

if __name__ == '__main__':
    sys.exit(main())
